# NAME

WWW::SwaggerClient::Role - a Moose role for the Newsletter2Go-API (https://api.newsletter2go.com)

<h5>JSON first</h5><br/>Our REST API exchanges data in the JSON data format. Every parameter you pass (with a few exceptions e.g. when you upload files) should therefore be formatted in JSON and our API will always return results in JSON as well.<br/><br/><h5>Very RESTful</h5><br/>Our API follows a very RESTful approach.<br/>Most importantly, we implemented the following four request methods for CRUD operations:<br/><br/>POST - Create a new record<br/>GET - Retrieve / read records without changing anything<br/>PATCH - Update an existing record<br/>DELETE - Delete one or more records<br/><br/><h5>HTTP Status codes</h5><br/>We also follow the most common HTTP status codes when outputting the API response:<br/><br/><b>2xx - Successful calls</b><br/>200 - Success<br/>201 - Created<br/><br/><b>4xx - Error codes</b><br/>400 - API error - inspect the body for detailed information about what went wrong. The most common error is \"code\":1062, which means, that a unique constraint was hit. For example if the name of the group is already in use.<br/>401 - Not authenticated - invalid access_token. Check if the access_token has expired or is incorrect.<br/>403 - Access denied<br/>404 - Call not available or no records found<br/><br/><b>5xx - API error - please contact support</b><br/><br/><h5>Response format</h5><br/>The API always returns data in the following format<br/><br/><code>{<br/>&nbsp;&nbsp;\"info\": {<br/>&nbsp;&nbsp;&nbsp;&nbsp;\"count\": 0<br/>&nbsp;&nbsp;},<br/>&nbsp;&nbsp;\"value\": [<br/>&nbsp;&nbsp;&nbsp;{<br/>&nbsp;&nbsp;&nbsp;&nbsp;\"key\": \"value\"<br/>&nbsp;&nbsp;&nbsp;}<br/>&nbsp;&nbsp;]<br/>}</code><br/><br/><h5>Recurring GET parameters</h5><br/><ul><li>_filter - a complex filter for filtering the result set based on <a target=\"blank\" href=\"https://tools.ietf.org/html/draft-nottingham-atompub-fiql-00\">FIQL</a>.</li><li>_limit - the maximum number records returned.</li><li>_offset - pagination for the result-set</li><li>_expand - submit true to get all default fields of the resource</li><li>_fields - submit a comma-separated list of case-sensetive field-names to get the values of these fields in the response. You can use this the get values of custom attribute of recipients for example.</li></ul><br/><br/><h5>Filter language</h5><br/>The filter language for filtering results is based on <a target=\"blank\" href=\"https://tools.ietf.org/html/draft-nottingham-atompub-fiql-00\">FIQL</a>.<br/>With the only restriction, that plain values must be surrounded by \". For example first_name==\"Max\"<br/>The following operators are supported<ul><li>Equals - <b>==</b></li><li>Not equals - <b>=ne=</b></li><li>Greater than - <b>=gt=</b></li><li>Greater than equals - <b>=ge=</b></li><li>Lower than - <b>=lt=</b></li><li>Lower than equals - <b>=le=</b></li><li>Like - <b>=like=</b> (in combination with % you are able to search for <i>starts with</i>, <i>ends with</i>, <i>contains</i>. For example first_name=like=\"%Max%\")</li><li>Not like - <b>=nlike=</b></li><li>Logical and - <b>;</b></li><li>Logical or - <b>,</b></li></ul><br/><br/><h5>How to make Calls?</h5><br/>After you authenticated and received a valid access_token, you have to pass it in every consecutive call. Use the Authorization header for that purpose as follows:<br/><code>xhr.setRequestHeader(\"Authorization\", \"Bearer \" + your_access_token);</code><br/><br/>Every call takes additional parameters that can be used to modify the request. These parameters should be passed as JSON<br/><code>var params = {<br/>&nbsp;&nbsp;\"key\"= \"value\"<br/>}<br/>xhr.send(JSON.stringify(params));</code><br/><br/><h5>Sending transactional emails</h5><br/>It is very important to understand the following concept in order for you to take full advantage of our powerful personalization features and our detailed reports when sending transactional emails.<br/><br/>First, you will have to create a new mailing. We recommend that you create that mailing through our UI in order to take full advantage of our powerful newsletter builder. This way, we will automatically create cross-client optimized and responsive HTML. Yet another advantage lies in the possibility for other users (e.g. the marketing team) to change the layout or the content of the mailing without having to contact the developer (you).<br/><br/>Of course, it is also possible to create a mailing through the API. When doing so, you can also take advantage of our cross-client optimized responsive HTML by passing us JSON or YAML according to the Newsletter2Go Markup Language.<br/>No matter how you create the mailing, try to create *one* reusable template. You can customize individual emails by inserting placeholders for personalized fields such as name, products or other information that will be filled through an API call when sending.<br/><br/>By only creating one template, you can take advantage of our full reporting since all emails will be treated part of a \"campaign\". When you change that template, we will create a new version of the mailing in the background and you will be able to see the difference in performance in the reports. This is particularily useful when you are trying to test and optimize different versions of transactional emails such as a sign up email.<br/><br/>After creating a mailing, you will have access to its ID. Use that ID to actually send the email in the next step.<br/><br/>When sending an email, you have to pass the newsletter ID and information about the recipient. Either pass the recipient ID or pass all the recipient's data (including the e-mail-address) as JSON.<br/><br/>If you only pass the recipient ID, we will use his or her data from your list to personalize the mailing. If you pass full recipient data as JSON, we will try to merge the data with existing data from your list.<br/><br/>You can also pass additional data such as product data which is not saved in your list. Just make sure that the placeholders in the source of the mailing correspond to the parameters that you are passing.<br/>This way you can also create for-loops which can be useful if you pass different amounts of data for each recipient (e.g. a purchase confirmation where you want to list all the products that were just bought).

# VERSION

Automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.0.0
- Build date: 2016-06-08T06:59:51.575Z
- Build package: class io.swagger.codegen.languages.PerlClientCodegen

## A note on Moose

This role is the only component of the library that uses Moose. See 
WWW::SwaggerClient::ApiFactory for non-Moosey usage. 

# SYNOPSIS

The Perl Swagger Codegen project builds a library of Perl modules to interact with 
a web service defined by a OpenAPI Specification. See below for how to build the 
library.

This module provides an interface to the generated library. All the classes, 
objects, and methods (well, not quite \*all\*, see below) are flattened into this 
role. 

        package MyApp;
        use Moose;
        with 'WWW::SwaggerClient::Role';
        
        package main;
        
        my $api = MyApp->new({ tokens => $tokens });
        
        my $pet = $api->get_pet_by_id(pet_id => $pet_id);
        

## Structure of the library

The library consists of a set of API classes, one for each endpoint. These APIs
implement the method calls available on each endpoint. 

Additionally, there is a set of "object" classes, which represent the objects 
returned by and sent to the methods on the endpoints. 

An API factory class is provided, which builds instances of each endpoint API. 

This Moose role flattens all the methods from the endpoint APIs onto the consuming 
class. It also provides methods to retrieve the endpoint API objects, and the API 
factory object, should you need it. 

For documentation of all these methods, see AUTOMATIC DOCUMENTATION below.

## Configuring authentication

In the normal case, the OpenAPI Spec will describe what parameters are
required and where to put them. You just need to supply the tokens.

    my $tokens = {
        # basic
        username => $username,
        password => $password,
        
        # oauth
        access_token => $oauth_token,
        
        # keys
        $some_key => { token => $token,
                       prefix => $prefix, 
                       in => $in,             # 'head||query',     
                       },
                       
        $another => { token => $token,
                      prefix => $prefix, 
                      in => $in,              # 'head||query',      
                      },                   
        ...,
        
        };
        
        my $api = MyApp->new({ tokens => $tokens });

Note these are all optional, as are `prefix` and `in`, and depend on the API
you are accessing. Usually `prefix` and `in` will be determined by the code generator from
the spec and you will not need to set them at run time. If not, `in` will
default to 'head' and `prefix` to the empty string. 

The tokens will be placed in the `WWW::SwaggerClient::Configuration` namespace
as follows, but you don't need to know about this. 

- `$WWW::SwaggerClient::Configuration::username`

    String. The username for basic auth.

- `$WWW::SwaggerClient::Configuration::password`

    String. The password for basic auth.

- `$WWW::SwaggerClient::Configuration::api_key`

    Hashref. Keyed on the name of each key (there can be multiple tokens).

            $WWW::SwaggerClient::Configuration::api_key = {
                    secretKey => 'aaaabbbbccccdddd',
                    anotherKey => '1111222233334444',
                    };

- `$WWW::SwaggerClient::Configuration::api_key_prefix`

    Hashref. Keyed on the name of each key (there can be multiple tokens). Note not
    all api keys require a prefix.

            $WWW::SwaggerClient::Configuration::api_key_prefix = {
                    secretKey => 'string',
                    anotherKey => 'same or some other string',
                    };

- `$WWW::SwaggerClient::Configuration::access_token`

    String. The OAuth access token. 

# METHODS

## `base_url`

The generated code has the `base_url` already set as a default value. This method 
returns (and optionally sets, but only if the API client has not been 
created yet) the current value of `base_url`.

## `api_factory`

Returns an API factory object. You probably won't need to call this directly. 

        $self->api_factory('Pet'); # returns a WWW::SwaggerClient::PetApi instance
        
        $self->pet_api;            # the same

# MISSING METHODS

Most of the methods on the API are delegated to individual endpoint API objects
(e.g. Pet API, Store API, User API etc). Where different endpoint APIs use the
same method name (e.g. `new()`), these methods can't be delegated. So you need
to call `$api->pet_api->new()`.

In principle, every API is susceptible to the presence of a few, random, undelegatable 
method names. In practice, because of the way method names are constructed, it's 
unlikely in general that any methods will be undelegatable, except for: 

        new()
        class_documentation()
        method_documentation()

To call these methods, you need to get a handle on the relevant object, either
by calling `$api->foo_api` or by retrieving an object, e.g.
`$api->get_pet_by_id(pet_id => $pet_id)`. They are class methods, so
you could also call them on class names.

# BUILDING YOUR LIBRARY

See the homepage `https://github.com/swagger-api/swagger-codegen` for full details. 
But briefly, clone the git repository, build the codegen codebase, set up your build 
config file, then run the API build script. You will need git, Java 7 or 8 and Apache
maven 3.0.3 or better already installed.

The config file should specify the project name for the generated library: 

        {"moduleName":"WWW::MyProjectName"}

Your library files will be built under `WWW::MyProjectName`.

          $ git clone https://github.com/swagger-api/swagger-codegen.git
          $ cd swagger-codegen
          $ mvn package
          $ java -jar modules/swagger-codegen-cli/target/swagger-codegen-cli.jar generate \
    -i [URL or file path to JSON swagger API spec] \
    -l perl \
    -c /path/to/config/file.json \
    -o /path/to/output/folder

Bang, all done. Run the `autodoc` script in the `bin` directory to see the API 
you just built. 

# AUTOMATIC DOCUMENTATION

You can print out a summary of the generated API by running the included
`autodoc` script in the `bin` directory of your generated library. A few
output formats are supported:

          Usage: autodoc [OPTION]

    -w           wide format (default)
    -n           narrow format
    -p           POD format 
    -H           HTML format 
    -m           Markdown format
    -h           print this help message
    -c           your application class
    

The `-c` option allows you to load and inspect your own application. A dummy
namespace is used if you don't supply your own class.

# DOCUMENTATION FROM THE OpenAPI Spec

Additional documentation for each class and method may be provided by the Swagger 
spec. If so, this is available via the `class_documentation()` and 
`method_documentation()` methods on each generated object class, and the 
`method_documentation()` method on the endpoint API classes: 

        my $cmdoc = $api->pet_api->method_documentation->{$method_name}; 
        
        my $odoc = $api->get_pet_by_id->(pet_id => $pet_id)->class_documentation;                                  
        my $omdoc = $api->get_pet_by_id->(pet_id => $pet_id)->method_documentation->{method_name}; 
        

Each of these calls returns a hashref with various useful pieces of information.

# LOAD THE MODULES

To load the API packages:
```perl
use WWW::SwaggerClient::AttributeApi;
use WWW::SwaggerClient::AuthorizationApi;
use WWW::SwaggerClient::CompanyApi;
use WWW::SwaggerClient::GroupApi;
use WWW::SwaggerClient::ListApi;
use WWW::SwaggerClient::NewsletterApi;
use WWW::SwaggerClient::RecipientApi;
use WWW::SwaggerClient::ReportApi;
use WWW::SwaggerClient::UserApi;

```

To load the models:
```perl
use WWW::SwaggerClient::Object::ApiResponseDelete;
use WWW::SwaggerClient::Object::ApiResponsePost;
use WWW::SwaggerClient::Object::AttributeGet;
use WWW::SwaggerClient::Object::AttributePatch;
use WWW::SwaggerClient::Object::AttributePost;
use WWW::SwaggerClient::Object::AttributeResponse;
use WWW::SwaggerClient::Object::CompanyGet;
use WWW::SwaggerClient::Object::CompanyPatch;
use WWW::SwaggerClient::Object::CompanyResponse;
use WWW::SwaggerClient::Object::Data;
use WWW::SwaggerClient::Object::Error;
use WWW::SwaggerClient::Object::GroupGet;
use WWW::SwaggerClient::Object::GroupPatch;
use WWW::SwaggerClient::Object::GroupPost;
use WWW::SwaggerClient::Object::GroupResponse;
use WWW::SwaggerClient::Object::ImportGet;
use WWW::SwaggerClient::Object::ImportResponse;
use WWW::SwaggerClient::Object::Info;
use WWW::SwaggerClient::Object::InlineResponse200;
use WWW::SwaggerClient::Object::ListGet;
use WWW::SwaggerClient::Object::ListPost;
use WWW::SwaggerClient::Object::ListResponse;
use WWW::SwaggerClient::Object::ModelWithId;
use WWW::SwaggerClient::Object::NewsletterGet;
use WWW::SwaggerClient::Object::NewsletterPost;
use WWW::SwaggerClient::Object::NewsletterResponse;
use WWW::SwaggerClient::Object::NewsletterSend;
use WWW::SwaggerClient::Object::PatchResponse;
use WWW::SwaggerClient::Object::RecipientGet;
use WWW::SwaggerClient::Object::RecipientPatch;
use WWW::SwaggerClient::Object::RecipientPost;
use WWW::SwaggerClient::Object::RecipientResponse;
use WWW::SwaggerClient::Object::RecipientSimple;
use WWW::SwaggerClient::Object::RecipientSubscribe;
use WWW::SwaggerClient::Object::RecipientSubscribeRecipient;
use WWW::SwaggerClient::Object::RecipientSubscribeResponse;
use WWW::SwaggerClient::Object::RecipientSubscribeResponseValue;
use WWW::SwaggerClient::Object::RecipientSubscribeResponseValueResult;
use WWW::SwaggerClient::Object::RecipientSubscribeResponseValueResultError;
use WWW::SwaggerClient::Object::RecipientSubscribeResponseValueResultErrorRecipients;
use WWW::SwaggerClient::Object::RecipientSubscribeResponseValueResultSuccess;
use WWW::SwaggerClient::Object::Report;
use WWW::SwaggerClient::Object::ReportResponse;
use WWW::SwaggerClient::Object::Token;
use WWW::SwaggerClient::Object::UserGet;
use WWW::SwaggerClient::Object::UserPatch;
use WWW::SwaggerClient::Object::UserResponse;

````

# GETTING STARTED
Put the Perl SDK under the 'lib' folder in your project directory, then run the following
```perl
#!/usr/bin/perl
use lib 'lib';
use strict;
use warnings;
# load the API package
use WWW::SwaggerClient::AttributeApi;
use WWW::SwaggerClient::AuthorizationApi;
use WWW::SwaggerClient::CompanyApi;
use WWW::SwaggerClient::GroupApi;
use WWW::SwaggerClient::ListApi;
use WWW::SwaggerClient::NewsletterApi;
use WWW::SwaggerClient::RecipientApi;
use WWW::SwaggerClient::ReportApi;
use WWW::SwaggerClient::UserApi;

# load the models
use WWW::SwaggerClient::Object::ApiResponseDelete;
use WWW::SwaggerClient::Object::ApiResponsePost;
use WWW::SwaggerClient::Object::AttributeGet;
use WWW::SwaggerClient::Object::AttributePatch;
use WWW::SwaggerClient::Object::AttributePost;
use WWW::SwaggerClient::Object::AttributeResponse;
use WWW::SwaggerClient::Object::CompanyGet;
use WWW::SwaggerClient::Object::CompanyPatch;
use WWW::SwaggerClient::Object::CompanyResponse;
use WWW::SwaggerClient::Object::Data;
use WWW::SwaggerClient::Object::Error;
use WWW::SwaggerClient::Object::GroupGet;
use WWW::SwaggerClient::Object::GroupPatch;
use WWW::SwaggerClient::Object::GroupPost;
use WWW::SwaggerClient::Object::GroupResponse;
use WWW::SwaggerClient::Object::ImportGet;
use WWW::SwaggerClient::Object::ImportResponse;
use WWW::SwaggerClient::Object::Info;
use WWW::SwaggerClient::Object::InlineResponse200;
use WWW::SwaggerClient::Object::ListGet;
use WWW::SwaggerClient::Object::ListPost;
use WWW::SwaggerClient::Object::ListResponse;
use WWW::SwaggerClient::Object::ModelWithId;
use WWW::SwaggerClient::Object::NewsletterGet;
use WWW::SwaggerClient::Object::NewsletterPost;
use WWW::SwaggerClient::Object::NewsletterResponse;
use WWW::SwaggerClient::Object::NewsletterSend;
use WWW::SwaggerClient::Object::PatchResponse;
use WWW::SwaggerClient::Object::RecipientGet;
use WWW::SwaggerClient::Object::RecipientPatch;
use WWW::SwaggerClient::Object::RecipientPost;
use WWW::SwaggerClient::Object::RecipientResponse;
use WWW::SwaggerClient::Object::RecipientSimple;
use WWW::SwaggerClient::Object::RecipientSubscribe;
use WWW::SwaggerClient::Object::RecipientSubscribeRecipient;
use WWW::SwaggerClient::Object::RecipientSubscribeResponse;
use WWW::SwaggerClient::Object::RecipientSubscribeResponseValue;
use WWW::SwaggerClient::Object::RecipientSubscribeResponseValueResult;
use WWW::SwaggerClient::Object::RecipientSubscribeResponseValueResultError;
use WWW::SwaggerClient::Object::RecipientSubscribeResponseValueResultErrorRecipients;
use WWW::SwaggerClient::Object::RecipientSubscribeResponseValueResultSuccess;
use WWW::SwaggerClient::Object::Report;
use WWW::SwaggerClient::Object::ReportResponse;
use WWW::SwaggerClient::Object::Token;
use WWW::SwaggerClient::Object::UserGet;
use WWW::SwaggerClient::Object::UserPatch;
use WWW::SwaggerClient::Object::UserResponse;

# for displaying the API response data
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::AttributeApi->new();
my $attribute = WWW::SwaggerClient::Object::AttributePost->new(); # AttributePost | the data to save

eval {
    my $result = $api_instance->create_attribute(attribute => $attribute);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling AttributeApi->create_attribute: $@\n";
}

```

# DOCUMENTATION FOR API ENDPOINTS

All URIs are relative to *https://api.newsletter2go.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AttributeApi* | [**create_attribute**](docs/AttributeApi.md#create_attribute) | **POST** /attributes | creates a new attribute
*AttributeApi* | [**delete_attribute**](docs/AttributeApi.md#delete_attribute) | **DELETE** /lists/{lid}/attributes/{id} | delete the attribute
*AttributeApi* | [**get_attributes**](docs/AttributeApi.md#get_attributes) | **GET** /lists/{lid}/attributes | get all Attributes of selected list
*AttributeApi* | [**update_attribute**](docs/AttributeApi.md#update_attribute) | **PATCH** /attributes/{id} | update the attribute
*AuthorizationApi* | [**get_token**](docs/AuthorizationApi.md#get_token) | **POST** /oauth/v2/token | Endpoint for retrieving a token
*CompanyApi* | [**get_company**](docs/CompanyApi.md#get_company) | **GET** /companies | get the details of a company
*CompanyApi* | [**update_company**](docs/CompanyApi.md#update_company) | **PATCH** /companies/{id} | update the Company
*GroupApi* | [**add_recipient_to_group**](docs/GroupApi.md#add_recipient_to_group) | **POST** /lists/{lid}/groups/{gid}/recipients/{id} | add single recipient to group
*GroupApi* | [**add_recipients_to_group**](docs/GroupApi.md#add_recipients_to_group) | **POST** /lists/{lid}/groups/{gid}/recipients | add all Recipients to the given group
*GroupApi* | [**create_group**](docs/GroupApi.md#create_group) | **POST** /groups | creates a new group
*GroupApi* | [**delete_group**](docs/GroupApi.md#delete_group) | **DELETE** /groups/{id} | delete the Group
*GroupApi* | [**get_groups**](docs/GroupApi.md#get_groups) | **GET** /lists/{lid}/groups | get all Group of selected list
*GroupApi* | [**get_recipients_by_group**](docs/GroupApi.md#get_recipients_by_group) | **GET** /lists/{lid}/groups/{gid}/recipients | get all Recipients of selected group
*GroupApi* | [**remove_recipient_from_group**](docs/GroupApi.md#remove_recipient_from_group) | **DELETE** /lists/{lid}/groups/{gid}/recipients/{id} | remove single recipient from group
*GroupApi* | [**remove_recipients_from_group**](docs/GroupApi.md#remove_recipients_from_group) | **DELETE** /lists/{lid}/groups/{gid}/recipients | remove all Recipients from given group
*GroupApi* | [**update_group**](docs/GroupApi.md#update_group) | **PATCH** /groups/{id} | update the Group
*ListApi* | [**create_list**](docs/ListApi.md#create_list) | **POST** /lists | creates a new list
*ListApi* | [**delete_list**](docs/ListApi.md#delete_list) | **DELETE** /lists/{id} | delete the List
*ListApi* | [**get_lists**](docs/ListApi.md#get_lists) | **GET** /lists | get all lists
*ListApi* | [**get_recipients**](docs/ListApi.md#get_recipients) | **GET** /lists/{lid}/recipients | get all Recipients of selected list
*ListApi* | [**remove_recipients_from_list**](docs/ListApi.md#remove_recipients_from_list) | **DELETE** /lists/{lid}/recipients | remove all Recipients from selected list
*ListApi* | [**update_list**](docs/ListApi.md#update_list) | **PATCH** /lists/{id} | update the List
*ListApi* | [**update_recipients**](docs/ListApi.md#update_recipients) | **PATCH** /lists/{lid}/recipients | update all Recipients in selected list
*NewsletterApi* | [**create_newsletter**](docs/NewsletterApi.md#create_newsletter) | **POST** /lists/{lid}/newsletters | creates a new newsletter
*NewsletterApi* | [**get_newsletter**](docs/NewsletterApi.md#get_newsletter) | **GET** /newsletters/{id} | get one newsletter
*NewsletterApi* | [**get_newsletters**](docs/NewsletterApi.md#get_newsletters) | **GET** /lists/{lid}/newsletters | get all newsletters of the given list
*NewsletterApi* | [**get_reports**](docs/NewsletterApi.md#get_reports) | **GET** /lists/{lid}/newsletters/{nid}/aggregations | get reports for the newsletter aggregated by days
*NewsletterApi* | [**send_newsletter**](docs/NewsletterApi.md#send_newsletter) | **POST** /newsletters/{id}/send | Sends the newsletter to a list or group
*NewsletterApi* | [**update_newsletter**](docs/NewsletterApi.md#update_newsletter) | **PATCH** /newsletters/{id} | update the Newsletter
*RecipientApi* | [**add_recipient_to_group**](docs/RecipientApi.md#add_recipient_to_group) | **POST** /lists/{lid}/groups/{gid}/recipients/{id} | add single recipient to group
*RecipientApi* | [**add_recipients_to_group**](docs/RecipientApi.md#add_recipients_to_group) | **POST** /lists/{lid}/groups/{gid}/recipients | add all Recipients to the given group
*RecipientApi* | [**create_recipient**](docs/RecipientApi.md#create_recipient) | **POST** /recipients | create new recipient(s) or updates existing ones
*RecipientApi* | [**delete_recipient**](docs/RecipientApi.md#delete_recipient) | **DELETE** /lists/{lid}/recipients/{id} | delete the recipient
*RecipientApi* | [**get_recipients**](docs/RecipientApi.md#get_recipients) | **GET** /lists/{lid}/recipients | get all Recipients of selected list
*RecipientApi* | [**get_recipients_by_group**](docs/RecipientApi.md#get_recipients_by_group) | **GET** /lists/{lid}/groups/{gid}/recipients | get all Recipients of selected group
*RecipientApi* | [**import_recipients_init**](docs/RecipientApi.md#import_recipients_init) | **POST** /lists/{lid}/recipients/import/init | Initialize the import of recipients by file
*RecipientApi* | [**import_recipients_save**](docs/RecipientApi.md#import_recipients_save) | **POST** /lists/{lid}/recipients/import/save | Start the import recipients by file
*RecipientApi* | [**import_recipients_statistics**](docs/RecipientApi.md#import_recipients_statistics) | **GET** /import/{id}/info | Get statistics about the import by file
*RecipientApi* | [**remove_recipient_from_group**](docs/RecipientApi.md#remove_recipient_from_group) | **DELETE** /lists/{lid}/groups/{gid}/recipients/{id} | remove single recipient from group
*RecipientApi* | [**remove_recipients_from_group**](docs/RecipientApi.md#remove_recipients_from_group) | **DELETE** /lists/{lid}/groups/{gid}/recipients | remove all Recipients from given group
*RecipientApi* | [**remove_recipients_from_list**](docs/RecipientApi.md#remove_recipients_from_list) | **DELETE** /lists/{lid}/recipients | remove all Recipients from selected list
*RecipientApi* | [**subscribe_recipient**](docs/RecipientApi.md#subscribe_recipient) | **POST** /forms/submit/{code} | Creates a new recipient and sends a DOI-Mail
*RecipientApi* | [**update_recipient**](docs/RecipientApi.md#update_recipient) | **PATCH** /lists/{lid}/recipients/{id} | update the recipient.
*RecipientApi* | [**update_recipients**](docs/RecipientApi.md#update_recipients) | **PATCH** /lists/{lid}/recipients | update all Recipients in selected list
*ReportApi* | [**get_reports**](docs/ReportApi.md#get_reports) | **GET** /lists/{lid}/newsletters/{nid}/aggregations | get reports for the newsletter aggregated by days
*UserApi* | [**get_users**](docs/UserApi.md#get_users) | **GET** /users | get all users of the company where the current user has access to
*UserApi* | [**update_user**](docs/UserApi.md#update_user) | **PATCH** /users/{id} | update the user


# DOCUMENTATION FOR MODELS
 - [WWW::SwaggerClient::Object::ApiResponseDelete](docs/ApiResponseDelete.md)
 - [WWW::SwaggerClient::Object::ApiResponsePost](docs/ApiResponsePost.md)
 - [WWW::SwaggerClient::Object::AttributeGet](docs/AttributeGet.md)
 - [WWW::SwaggerClient::Object::AttributePatch](docs/AttributePatch.md)
 - [WWW::SwaggerClient::Object::AttributePost](docs/AttributePost.md)
 - [WWW::SwaggerClient::Object::AttributeResponse](docs/AttributeResponse.md)
 - [WWW::SwaggerClient::Object::CompanyGet](docs/CompanyGet.md)
 - [WWW::SwaggerClient::Object::CompanyPatch](docs/CompanyPatch.md)
 - [WWW::SwaggerClient::Object::CompanyResponse](docs/CompanyResponse.md)
 - [WWW::SwaggerClient::Object::Data](docs/Data.md)
 - [WWW::SwaggerClient::Object::Error](docs/Error.md)
 - [WWW::SwaggerClient::Object::GroupGet](docs/GroupGet.md)
 - [WWW::SwaggerClient::Object::GroupPatch](docs/GroupPatch.md)
 - [WWW::SwaggerClient::Object::GroupPost](docs/GroupPost.md)
 - [WWW::SwaggerClient::Object::GroupResponse](docs/GroupResponse.md)
 - [WWW::SwaggerClient::Object::ImportGet](docs/ImportGet.md)
 - [WWW::SwaggerClient::Object::ImportResponse](docs/ImportResponse.md)
 - [WWW::SwaggerClient::Object::Info](docs/Info.md)
 - [WWW::SwaggerClient::Object::InlineResponse200](docs/InlineResponse200.md)
 - [WWW::SwaggerClient::Object::ListGet](docs/ListGet.md)
 - [WWW::SwaggerClient::Object::ListPost](docs/ListPost.md)
 - [WWW::SwaggerClient::Object::ListResponse](docs/ListResponse.md)
 - [WWW::SwaggerClient::Object::ModelWithId](docs/ModelWithId.md)
 - [WWW::SwaggerClient::Object::NewsletterGet](docs/NewsletterGet.md)
 - [WWW::SwaggerClient::Object::NewsletterPost](docs/NewsletterPost.md)
 - [WWW::SwaggerClient::Object::NewsletterResponse](docs/NewsletterResponse.md)
 - [WWW::SwaggerClient::Object::NewsletterSend](docs/NewsletterSend.md)
 - [WWW::SwaggerClient::Object::PatchResponse](docs/PatchResponse.md)
 - [WWW::SwaggerClient::Object::RecipientGet](docs/RecipientGet.md)
 - [WWW::SwaggerClient::Object::RecipientPatch](docs/RecipientPatch.md)
 - [WWW::SwaggerClient::Object::RecipientPost](docs/RecipientPost.md)
 - [WWW::SwaggerClient::Object::RecipientResponse](docs/RecipientResponse.md)
 - [WWW::SwaggerClient::Object::RecipientSimple](docs/RecipientSimple.md)
 - [WWW::SwaggerClient::Object::RecipientSubscribe](docs/RecipientSubscribe.md)
 - [WWW::SwaggerClient::Object::RecipientSubscribeRecipient](docs/RecipientSubscribeRecipient.md)
 - [WWW::SwaggerClient::Object::RecipientSubscribeResponse](docs/RecipientSubscribeResponse.md)
 - [WWW::SwaggerClient::Object::RecipientSubscribeResponseValue](docs/RecipientSubscribeResponseValue.md)
 - [WWW::SwaggerClient::Object::RecipientSubscribeResponseValueResult](docs/RecipientSubscribeResponseValueResult.md)
 - [WWW::SwaggerClient::Object::RecipientSubscribeResponseValueResultError](docs/RecipientSubscribeResponseValueResultError.md)
 - [WWW::SwaggerClient::Object::RecipientSubscribeResponseValueResultErrorRecipients](docs/RecipientSubscribeResponseValueResultErrorRecipients.md)
 - [WWW::SwaggerClient::Object::RecipientSubscribeResponseValueResultSuccess](docs/RecipientSubscribeResponseValueResultSuccess.md)
 - [WWW::SwaggerClient::Object::Report](docs/Report.md)
 - [WWW::SwaggerClient::Object::ReportResponse](docs/ReportResponse.md)
 - [WWW::SwaggerClient::Object::Token](docs/Token.md)
 - [WWW::SwaggerClient::Object::UserGet](docs/UserGet.md)
 - [WWW::SwaggerClient::Object::UserPatch](docs/UserPatch.md)
 - [WWW::SwaggerClient::Object::UserResponse](docs/UserResponse.md)


# DOCUMENTATION FOR AUTHORIATION

## OAuth

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: /oauth/v2/token
- **Scopes**: N/A

## Basic

- **Type**: HTTP basic authentication



