# WWW::SwaggerClient::NewsletterApi

## Load the API package
```perl
use WWW::SwaggerClient::Object::NewsletterApi;
```

All URIs are relative to *https://api.newsletter2go.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_newsletter**](NewsletterApi.md#create_newsletter) | **POST** /lists/{lid}/newsletters | creates a new newsletter
[**get_newsletter**](NewsletterApi.md#get_newsletter) | **GET** /newsletters/{id} | get one newsletter
[**get_newsletters**](NewsletterApi.md#get_newsletters) | **GET** /lists/{lid}/newsletters | get all newsletters of the given list
[**get_reports**](NewsletterApi.md#get_reports) | **GET** /lists/{lid}/newsletters/{nid}/aggregations | get reports for the newsletter aggregated by days
[**send_newsletter**](NewsletterApi.md#send_newsletter) | **POST** /newsletters/{id}/send | Sends the newsletter to a list or group
[**update_newsletter**](NewsletterApi.md#update_newsletter) | **PATCH** /newsletters/{id} | update the Newsletter


# **create_newsletter**
> ApiResponsePost create_newsletter(lid => $lid, newsletter => $newsletter)

creates a new newsletter

creates a new Newsletter

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::NewsletterApi->new();
my $lid = 'lid_example'; # string | the id of the list
my $newsletter = WWW::SwaggerClient::Object::NewsletterPost->new(); # NewsletterPost | the data to save

eval { 
    my $result = $api_instance->create_newsletter(lid => $lid, newsletter => $newsletter);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling NewsletterApi->create_newsletter: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **lid** | **string**| the id of the list | 
 **newsletter** | [**NewsletterPost**](NewsletterPost.md)| the data to save | 

### Return type

[**ApiResponsePost**](ApiResponsePost.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_newsletter**
> NewsletterResponse get_newsletter(id => $id, _filter => $_filter, _fields => $_fields)

get one newsletter

get Newsletter

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::NewsletterApi->new();
my $id = 'id_example'; # string | the id of the newsletter
my $_filter = '_filter_example'; # string | a FIQL-Filter
my $_fields = (); # ARRAY[string] | list of case-sensetive fields which should be returned.    Only needed if _expand is false or special attributes are needed

eval { 
    my $result = $api_instance->get_newsletter(id => $id, _filter => $_filter, _fields => $_fields);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling NewsletterApi->get_newsletter: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **string**| the id of the newsletter | 
 **_filter** | **string**| a FIQL-Filter | [optional] 
 **_fields** | [**ARRAY[string]**](string.md)| list of case-sensetive fields which should be returned.    Only needed if _expand is false or special attributes are needed | [optional] 

### Return type

[**NewsletterResponse**](NewsletterResponse.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_newsletters**
> NewsletterResponse get_newsletters(lid => $lid, _filter => $_filter, _limit => $_limit, _offset => $_offset, _expand => $_expand, _fields => $_fields)

get all newsletters of the given list

get Newsletters

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::NewsletterApi->new();
my $lid = 'lid_example'; # string | the id of the list
my $_filter = '_filter_example'; # string | a FIQL-Filter
my $_limit = 56; # int | a limit for list-responses
my $_offset = 56; # int | an offset for list-responses
my $_expand = 1; # boolean | true if attributes should be returned or not
my $_fields = (); # ARRAY[string] | list of case-sensetive fields which should be returned.    Only needed if _expand is false or special attributes are needed

eval { 
    my $result = $api_instance->get_newsletters(lid => $lid, _filter => $_filter, _limit => $_limit, _offset => $_offset, _expand => $_expand, _fields => $_fields);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling NewsletterApi->get_newsletters: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **lid** | **string**| the id of the list | 
 **_filter** | **string**| a FIQL-Filter | [optional] 
 **_limit** | **int**| a limit for list-responses | [optional] [default to 50]
 **_offset** | **int**| an offset for list-responses | [optional] [default to 0]
 **_expand** | **boolean**| true if attributes should be returned or not | [optional] 
 **_fields** | [**ARRAY[string]**](string.md)| list of case-sensetive fields which should be returned.    Only needed if _expand is false or special attributes are needed | [optional] 

### Return type

[**NewsletterResponse**](NewsletterResponse.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_reports**
> ReportResponse get_reports(_filter => $_filter, _limit => $_limit, _offset => $_offset, _expand => $_expand, _fields => $_fields)

get reports for the newsletter aggregated by days

get reports for the newsletter aggregated by days

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::NewsletterApi->new();
my $_filter = '_filter_example'; # string | a FIQL-Filter
my $_limit = 56; # int | a limit for list-responses
my $_offset = 56; # int | an offset for list-responses
my $_expand = 1; # boolean | true if attributes should be returned or not
my $_fields = (); # ARRAY[string] | list of case-sensetive fields which should be returned.    Only needed if _expand is false or special attributes are needed

eval { 
    my $result = $api_instance->get_reports(_filter => $_filter, _limit => $_limit, _offset => $_offset, _expand => $_expand, _fields => $_fields);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling NewsletterApi->get_reports: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **_filter** | **string**| a FIQL-Filter | [optional] 
 **_limit** | **int**| a limit for list-responses | [optional] [default to 50]
 **_offset** | **int**| an offset for list-responses | [optional] [default to 0]
 **_expand** | **boolean**| true if attributes should be returned or not | [optional] 
 **_fields** | [**ARRAY[string]**](string.md)| list of case-sensetive fields which should be returned.    Only needed if _expand is false or special attributes are needed | [optional] 

### Return type

[**ReportResponse**](ReportResponse.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_newsletter**
> send_newsletter(id => $id, newsletter => $newsletter)

Sends the newsletter to a list or group



### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::NewsletterApi->new();
my $id = 'id_example'; # string | the id of the list
my $newsletter = WWW::SwaggerClient::Object::NewsletterSend->new(); # NewsletterSend | the data to save

eval { 
    $api_instance->send_newsletter(id => $id, newsletter => $newsletter);
};
if ($@) {
    warn "Exception when calling NewsletterApi->send_newsletter: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **string**| the id of the list | 
 **newsletter** | [**NewsletterSend**](NewsletterSend.md)| the data to save | 

### Return type

void (empty response body)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_newsletter**
> PatchResponse update_newsletter(id => $id, newsletter => $newsletter)

update the Newsletter

update one Newsletter

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::NewsletterApi->new();
my $id = 'id_example'; # string | the id of the newsletter
my $newsletter = WWW::SwaggerClient::Object::NewsletterPost->new(); # NewsletterPost | the data to update

eval { 
    my $result = $api_instance->update_newsletter(id => $id, newsletter => $newsletter);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling NewsletterApi->update_newsletter: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **string**| the id of the newsletter | 
 **newsletter** | [**NewsletterPost**](NewsletterPost.md)| the data to update | 

### Return type

[**PatchResponse**](PatchResponse.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

