# WWW::SwaggerClient::RecipientApi

## Load the API package
```perl
use WWW::SwaggerClient::Object::RecipientApi;
```

All URIs are relative to *https://api.newsletter2go.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**add_recipient_to_group**](RecipientApi.md#add_recipient_to_group) | **POST** /lists/{lid}/groups/{gid}/recipients/{id} | add single recipient to group
[**add_recipients_to_group**](RecipientApi.md#add_recipients_to_group) | **POST** /lists/{lid}/groups/{gid}/recipients | add all Recipients to the given group
[**create_recipient**](RecipientApi.md#create_recipient) | **POST** /recipients | create new recipient(s) or updates existing ones
[**delete_recipient**](RecipientApi.md#delete_recipient) | **DELETE** /lists/{lid}/recipients/{id} | delete the recipient
[**get_recipients**](RecipientApi.md#get_recipients) | **GET** /lists/{lid}/recipients | get all Recipients of selected list
[**get_recipients_by_group**](RecipientApi.md#get_recipients_by_group) | **GET** /lists/{lid}/groups/{gid}/recipients | get all Recipients of selected group
[**import_recipients_init**](RecipientApi.md#import_recipients_init) | **POST** /lists/{lid}/recipients/import/init | Initialize the import of recipients by file
[**import_recipients_save**](RecipientApi.md#import_recipients_save) | **POST** /lists/{lid}/recipients/import/save | Start the import recipients by file
[**import_recipients_statistics**](RecipientApi.md#import_recipients_statistics) | **GET** /import/{id}/info | Get statistics about the import by file
[**remove_recipient_from_group**](RecipientApi.md#remove_recipient_from_group) | **DELETE** /lists/{lid}/groups/{gid}/recipients/{id} | remove single recipient from group
[**remove_recipients_from_group**](RecipientApi.md#remove_recipients_from_group) | **DELETE** /lists/{lid}/groups/{gid}/recipients | remove all Recipients from given group
[**remove_recipients_from_list**](RecipientApi.md#remove_recipients_from_list) | **DELETE** /lists/{lid}/recipients | remove all Recipients from selected list
[**subscribe_recipient**](RecipientApi.md#subscribe_recipient) | **POST** /forms/submit/{code} | Creates a new recipient and sends a DOI-Mail
[**update_recipient**](RecipientApi.md#update_recipient) | **PATCH** /lists/{lid}/recipients/{id} | update the recipient.
[**update_recipients**](RecipientApi.md#update_recipients) | **PATCH** /lists/{lid}/recipients | update all Recipients in selected list


# **add_recipient_to_group**
> PatchResponse add_recipient_to_group(lid => $lid, gid => $gid, id => $id)

add single recipient to group

add Recipient to Group

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::RecipientApi->new();
my $lid = 'lid_example'; # string | the id of the list
my $gid = 'gid_example'; # string | the id of the group
my $id = 'id_example'; # string | the id of the recipient

eval { 
    my $result = $api_instance->add_recipient_to_group(lid => $lid, gid => $gid, id => $id);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling RecipientApi->add_recipient_to_group: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **lid** | **string**| the id of the list | 
 **gid** | **string**| the id of the group | 
 **id** | **string**| the id of the recipient | 

### Return type

[**PatchResponse**](PatchResponse.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **add_recipients_to_group**
> PatchResponse add_recipients_to_group(lid => $lid, gid => $gid, _filter => $_filter)

add all Recipients to the given group

add all Recipients to the given group. Pay attention to the filter, if you forget to submit it, all recipients of the current list are getting added to the group!

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::RecipientApi->new();
my $lid = 'lid_example'; # string | the id of the list
my $gid = 'gid_example'; # string | the id of the group
my $_filter = '_filter_example'; # string | a FIQL-Filter

eval { 
    my $result = $api_instance->add_recipients_to_group(lid => $lid, gid => $gid, _filter => $_filter);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling RecipientApi->add_recipients_to_group: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **lid** | **string**| the id of the list | 
 **gid** | **string**| the id of the group | 
 **_filter** | **string**| a FIQL-Filter | [optional] 

### Return type

[**PatchResponse**](PatchResponse.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_recipient**
> ApiResponsePost create_recipient(recipient => $recipient)

create new recipient(s) or updates existing ones

create new recipient(s).<br>If a custom attribute shall by saved for the new recipient just submit them in the json body by name.<br>If <b>multiple recipients</b> shall by saved at once, submit multiple recipient-objects as a json array.<br><b>In this case all objects must share the same attributes.</b><br/>If the e-mail-address exists already the existing recipient gets updated.

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::RecipientApi->new();
my $recipient = WWW::SwaggerClient::Object::RecipientPost->new(); # RecipientPost | the data to save

eval { 
    my $result = $api_instance->create_recipient(recipient => $recipient);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling RecipientApi->create_recipient: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **recipient** | [**RecipientPost**](RecipientPost.md)| the data to save | 

### Return type

[**ApiResponsePost**](ApiResponsePost.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_recipient**
> ApiResponseDelete delete_recipient(lid => $lid, id => $id)

delete the recipient

delete one recipient

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::RecipientApi->new();
my $lid = 'lid_example'; # string | the id of the list
my $id = 'id_example'; # string | the id of the recipient

eval { 
    my $result = $api_instance->delete_recipient(lid => $lid, id => $id);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling RecipientApi->delete_recipient: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **lid** | **string**| the id of the list | 
 **id** | **string**| the id of the recipient | 

### Return type

[**ApiResponseDelete**](ApiResponseDelete.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_recipients**
> RecipientResponse get_recipients(lid => $lid, _filter => $_filter, _limit => $_limit, _offset => $_offset, _expand => $_expand, _fields => $_fields)

get all Recipients of selected list

Get Recipients. If the API shall return custom attributes also, submit them in the _fields-Parameter by name.

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::RecipientApi->new();
my $lid = 'lid_example'; # string | the id of the list
my $_filter = '_filter_example'; # string | a FIQL-Filter
my $_limit = 56; # int | a limit for list-responses
my $_offset = 56; # int | an offset for list-responses
my $_expand = 1; # boolean | true if attributes should be returned or not
my $_fields = (); # ARRAY[string] | list of case-sensetive fields which should be returned.    Only needed if _expand is false or special attributes are needed

eval { 
    my $result = $api_instance->get_recipients(lid => $lid, _filter => $_filter, _limit => $_limit, _offset => $_offset, _expand => $_expand, _fields => $_fields);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling RecipientApi->get_recipients: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **lid** | **string**| the id of the list | 
 **_filter** | **string**| a FIQL-Filter | [optional] 
 **_limit** | **int**| a limit for list-responses | [optional] [default to 50]
 **_offset** | **int**| an offset for list-responses | [optional] [default to 0]
 **_expand** | **boolean**| true if attributes should be returned or not | [optional] 
 **_fields** | [**ARRAY[string]**](string.md)| list of case-sensetive fields which should be returned.    Only needed if _expand is false or special attributes are needed | [optional] 

### Return type

[**RecipientResponse**](RecipientResponse.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_recipients_by_group**
> RecipientResponse get_recipients_by_group(lid => $lid, gid => $gid, _filter => $_filter, _limit => $_limit, _offset => $_offset, _expand => $_expand, _fields => $_fields)

get all Recipients of selected group

get Recipients

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::RecipientApi->new();
my $lid = 'lid_example'; # string | the id of the list
my $gid = 'gid_example'; # string | the id of the group
my $_filter = '_filter_example'; # string | a FIQL-Filter
my $_limit = 56; # int | a limit for list-responses
my $_offset = 56; # int | an offset for list-responses
my $_expand = 1; # boolean | true if attributes should be returned or not
my $_fields = (); # ARRAY[string] | list of case-sensetive fields which should be returned.    Only needed if _expand is false or special attributes are needed

eval { 
    my $result = $api_instance->get_recipients_by_group(lid => $lid, gid => $gid, _filter => $_filter, _limit => $_limit, _offset => $_offset, _expand => $_expand, _fields => $_fields);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling RecipientApi->get_recipients_by_group: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **lid** | **string**| the id of the list | 
 **gid** | **string**| the id of the group | 
 **_filter** | **string**| a FIQL-Filter | [optional] 
 **_limit** | **int**| a limit for list-responses | [optional] [default to 50]
 **_offset** | **int**| an offset for list-responses | [optional] [default to 0]
 **_expand** | **boolean**| true if attributes should be returned or not | [optional] 
 **_fields** | [**ARRAY[string]**](string.md)| list of case-sensetive fields which should be returned.    Only needed if _expand is false or special attributes are needed | [optional] 

### Return type

[**RecipientResponse**](RecipientResponse.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **import_recipients_init**
> InlineResponse200 import_recipients_init(lid => $lid, file => $file)

Initialize the import of recipients by file

Initialize the import recipients by file

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::RecipientApi->new();
my $lid = 'lid_example'; # string | the id of the list
my $file = '/path/to/file.txt'; # File | recipient file to upload

eval { 
    my $result = $api_instance->import_recipients_init(lid => $lid, file => $file);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling RecipientApi->import_recipients_init: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **lid** | **string**| the id of the list | 
 **file** | **File**| recipient file to upload | 

### Return type

[**InlineResponse200**](InlineResponse200.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: multipart/form-data
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **import_recipients_save**
> ApiResponsePost import_recipients_save(lid => $lid, data => $data)

Start the import recipients by file

Start the import recipients by file. The returned id can be used to fetch further statistics about the import.

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::RecipientApi->new();
my $lid = 'lid_example'; # string | the id of the list
my $data = WWW::SwaggerClient::Object::Data->new(); # Data | the data to start the import

eval { 
    my $result = $api_instance->import_recipients_save(lid => $lid, data => $data);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling RecipientApi->import_recipients_save: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **lid** | **string**| the id of the list | 
 **data** | [**Data**](Data.md)| the data to start the import | 

### Return type

[**ApiResponsePost**](ApiResponsePost.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **import_recipients_statistics**
> ImportResponse import_recipients_statistics(id => $id)

Get statistics about the import by file

Get statistics about the import by file.

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::RecipientApi->new();
my $id = 'id_example'; # string | the id of the import job

eval { 
    my $result = $api_instance->import_recipients_statistics(id => $id);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling RecipientApi->import_recipients_statistics: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **string**| the id of the import job | 

### Return type

[**ImportResponse**](ImportResponse.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **remove_recipient_from_group**
> PatchResponse remove_recipient_from_group(lid => $lid, gid => $gid, id => $id)

remove single recipient from group

remove Recipient to Group

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::RecipientApi->new();
my $lid = 'lid_example'; # string | the id of the list
my $gid = 'gid_example'; # string | the id of the group
my $id = 'id_example'; # string | the id of the recipient

eval { 
    my $result = $api_instance->remove_recipient_from_group(lid => $lid, gid => $gid, id => $id);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling RecipientApi->remove_recipient_from_group: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **lid** | **string**| the id of the list | 
 **gid** | **string**| the id of the group | 
 **id** | **string**| the id of the recipient | 

### Return type

[**PatchResponse**](PatchResponse.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **remove_recipients_from_group**
> PatchResponse remove_recipients_from_group(lid => $lid, gid => $gid, _filter => $_filter)

remove all Recipients from given group

remove all Recipients from given group. Pay attention to the filter, if you forget to submit it, all recipients are getting removed from the group!

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::RecipientApi->new();
my $lid = 'lid_example'; # string | the id of the list
my $gid = 'gid_example'; # string | the id of the group
my $_filter = '_filter_example'; # string | a FIQL-Filter

eval { 
    my $result = $api_instance->remove_recipients_from_group(lid => $lid, gid => $gid, _filter => $_filter);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling RecipientApi->remove_recipients_from_group: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **lid** | **string**| the id of the list | 
 **gid** | **string**| the id of the group | 
 **_filter** | **string**| a FIQL-Filter | [optional] 

### Return type

[**PatchResponse**](PatchResponse.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **remove_recipients_from_list**
> PatchResponse remove_recipients_from_list(lid => $lid, _filter => $_filter)

remove all Recipients from selected list

remove Recipients from selected list. Pay attention to the filter, if you forget to submit it, all recipients of the current list are getting removed!

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::RecipientApi->new();
my $lid = 'lid_example'; # string | the id of the list
my $_filter = '_filter_example'; # string | a FIQL-Filter

eval { 
    my $result = $api_instance->remove_recipients_from_list(lid => $lid, _filter => $_filter);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling RecipientApi->remove_recipients_from_list: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **lid** | **string**| the id of the list | 
 **_filter** | **string**| a FIQL-Filter | [optional] 

### Return type

[**PatchResponse**](PatchResponse.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **subscribe_recipient**
> RecipientSubscribeResponse subscribe_recipient(code => $code, recipient => $recipient)

Creates a new recipient and sends a DOI-Mail

Creates a new recipient and sends the corresponding DOI-Mail attached to the previously created subscribe-form. The recipient will be available as soon as the recipient has confirmed the DOI-Mail.

### Example 
```perl
use Data::Dumper;

my $api_instance = WWW::SwaggerClient::RecipientApi->new();
my $code = 'code_example'; # string | the subscribe-code displayed when creating a subscribe-form
my $recipient = WWW::SwaggerClient::Object::RecipientSubscribe->new(); # RecipientSubscribe | the recipient to subscribe

eval { 
    my $result = $api_instance->subscribe_recipient(code => $code, recipient => $recipient);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling RecipientApi->subscribe_recipient: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **code** | **string**| the subscribe-code displayed when creating a subscribe-form | 
 **recipient** | [**RecipientSubscribe**](RecipientSubscribe.md)| the recipient to subscribe | 

### Return type

[**RecipientSubscribeResponse**](RecipientSubscribeResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_recipient**
> PatchResponse update_recipient(lid => $lid, id => $id, recipient => $recipient)

update the recipient.

update one Recipient. If a value of a custom attribute shall by changed just submit it in the json body

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::RecipientApi->new();
my $lid = 'lid_example'; # string | the id of the list
my $id = 'id_example'; # string | the id of the recipient
my $recipient = WWW::SwaggerClient::Object::RecipientPatch->new(); # RecipientPatch | the data to update

eval { 
    my $result = $api_instance->update_recipient(lid => $lid, id => $id, recipient => $recipient);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling RecipientApi->update_recipient: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **lid** | **string**| the id of the list | 
 **id** | **string**| the id of the recipient | 
 **recipient** | [**RecipientPatch**](RecipientPatch.md)| the data to update | 

### Return type

[**PatchResponse**](PatchResponse.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_recipients**
> PatchResponse update_recipients(lid => $lid, _filter => $_filter)

update all Recipients in selected list

Updates all recipients in the given list where the filter applies. If a value of a custom attribute shall by changed just submit it in the json body. Pay attention to the filter, if you forget to submit it, all recipients of the current list are getting updated!

### Example 
```perl
use Data::Dumper;

# Configure OAuth2 access token for authorization: OAuth
$WWW::SwaggerClient::Configuration::access_token = 'YOUR_ACCESS_TOKEN';

my $api_instance = WWW::SwaggerClient::RecipientApi->new();
my $lid = 'lid_example'; # string | the id of the list
my $_filter = '_filter_example'; # string | a FIQL-Filter

eval { 
    my $result = $api_instance->update_recipients(lid => $lid, _filter => $_filter);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling RecipientApi->update_recipients: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **lid** | **string**| the id of the list | 
 **_filter** | **string**| a FIQL-Filter | [optional] 

### Return type

[**PatchResponse**](PatchResponse.md)

### Authorization

[OAuth](../README.md#OAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

